<?php

	/**
	 *
	 *
	 * @wordpress-plugin
	 * Plugin Name:       CTLT Blockquote Shortcode
	 * Plugin URI:        http://ctlt.ubc.ca/
	 * Description:       
	 * Version:           1.0
	 * Author:            Richard Tape
	 * Author URI:        http://blogs.ubc.ca/mbcx9rvt
	 * License:           GPL-2.0+
	 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
	 * Text Domain:       ctlt-blockquote-shortcode
	 * Domain Path:       /languages
	 */

	// If this file is called directly, abort.
	if ( ! defined( 'WPINC' ) ) {
		die;
	}

	class CTLT_Blockquote_Shortcode {

		// used to tell if SliderBlockquoteShortcode is on page or post
		static $add_script;
		/**
		 * Set up our actions and filters
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param null
		 * @return null
		 */


		public function __construct() {

			// Register the shortcodes
			add_action( 'init', array( $this, 'init__registerShortCodes' ) );

			// Register the shortcake integration
			add_action( 'init', array( $this, 'init__registerShortcakeIntegration' ) );

			add_action('wp_footer', array( $this, 'print_script' ) );

			add_action('init', array( $this, 'registerSingleBlockquoteShortcodeScript' ) );

		}/* __construct() */


		/**
		 * Registers js for SliderBlockQuoteShortcode
		 *
		 * @author David Brabbins
		 * @since 1.0.5
		 * @param null
		 * @return null
		 */

		public function registerSingleBlockquoteShortcodeScript() {
			wp_register_script('blockquote-slider', plugins_url('../../assets/js/blockquote-slider.js', __FILE__), array('jquery'), '1.0', true);
		}

		/**
		 * prints script
		 *
		 * @author David Brabbins
		 * @since 1.0.5
		 * @param $add_script 
		 * @return enqueues script if true blockquote-slider
		 */
		

		public function print_script() {
			if ( ! self::$add_script )
				return;

			wp_print_scripts('blockquote-slider');
		}
		

		/**
		 * Make the call to add_shortcode on init
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param null
		 * @return null
		 */
		
		public function init__registerShortCodes() {

			// The shortcode for a single blockquote
			add_shortcode( 'ctlt-blockquote-single', array( $this, 'add_shortcode__registerSingleBlockquoteShortcode' ) );
			
			// The shortcode for a slider of blockquotes
			add_shortcode( 'ctlt-blockquote-slider', array( $this, 'add_shortcode__registerSliderBlockquoteShortcode' ) );

		}/* init__registerShortCodes() */


		/**
		 * The callback function for the single shortcode
		 * [ctlt_blockquote_single testimonial="21"] -- Would fetch the details of the CPT 'testimonial'
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (array) $atts - The attributes for this array
		 * @return (string) - $output - the Markup returned by this shortcode
		 */
		
		public function add_shortcode__registerSingleBlockquoteShortcode( $atts ) {

			$mergedAtts = shortcode_atts(
				array( 
					'testimonial' => null
				),
				$atts
			);

			// No ID passed? Bail
			if( !isset( $mergedAtts['testimonial'] ) || empty( $mergedAtts['testimonial'] ) || $mergedAtts['testimonial'] == null ) {
				return '<!-- A blockquote would be here, but no Testimonial ID was passed -->';
			}

			// Check validity of post ID
			$isValidTestimonial = $this->checkPostIDIsValidTestimonial( $mergedAtts['testimonial'] );

			if( !is_array( $isValidTestimonial ) ) {
				return $isValidTestimonial;
			}

			$cite 		= $isValidTestimonial['cite'];
			$quote 		= $isValidTestimonial['quote'];
			$url 		= $isValidTestimonial['url'];
			
			// OK, all checks passed, we now need to output
			return $this->getMarkupForSingleBlockquote( $cite, $quote, $url );

		}/* add_shortcode__registerSingleBlockquoteShortcode() */


		/**
		 * The callback function for the slider shortcode
		 * [ctlt_blockquote_slider testimonials="21,42,63"] -- Would fetch the details of the CPT 'testimonial' with those IDs
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (array) $atts - The attributes for this aray
		 * @return (string) - $output - the Markup returned by this shortcode
		 */
		
		public function add_shortcode__registerSliderBlockquoteShortcode( $atts ) {
			
			self::$add_script = true;

			$mergedAtts = shortcode_atts(
				array( 
					'testimonials' => null
				),
				$atts
			);

			// Ensure that we have a csv list of testimonials
			if( !isset( $mergedAtts['testimonials'] ) || empty( $mergedAtts['testimonials'] ) || $mergedAtts['testimonials'] == null ) {
				return '<!-- A slider of blockquotes would be here, but a comma separated string of testimonials was not passed -->';
			}

			// Fetch as a string and then split into an array
			$postIDsString = $mergedAtts['testimonials'];

			// Allow people to use 1, 2, 4, 5  and   1,2,3,4 (i.e. with and without spaces)
			$postIDsArray = array_map( 'trim', explode( ',', $postIDsString ) );

			if( empty( $postIDsArray ) ) {
				return '<!-- A slider of blockquotes would be here but the string passed was not valid -->';
			}

			// Start our output
			$output = apply_filters( 'ctlt_blockquote_slider_opening_markup', '<ul class="ctlt-testimonials-slider">' );

			foreach ( $postIDsArray as $key => $postID ) {
				
				// Check the validity of the PostID
				$validity = $this->checkPostIDIsValidTestimonial( $postID );

				// If we don't have an array back from the validity checker, add the error message to our string and bail
				if( !is_array( $validity ) ) {
					$output .= $validity;
					continue;
				}

				// Add the markup for this blockquote
				$cite 	= $validity['cite'];
				$quote 	= $validity['quote'];
				$url 	= $validity['url'];
			
				// OK, all checks passed, we now need to output
				$output .= $this->getMarkupForSingleBlockQuoteInSlider( $cite, $quote, $url );

			}

			// End our output by closing the list
			$output .= apply_filters( 'ctlt_blockquote_slider_closing_markup', '</ul>' );

			return $output;

		}/* add_shortcode__registerSliderBlockquoteShortcode() */


		/**
		 * Single method to check validity of the passed ID for the shortcode
		 * Checks for an ID being passed, That the ID is the right post type, That this post has the correct fields
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (int) $postID - The ID to check
		 * @return (mixed) - A string if there's an error, or an array of quote and cite if the post is valid
		 */

		protected function checkPostIDIsValidTestimonial( $postID ) {

			// Sanitize
			$testimonialIDToFetch = absint( $postID );

			// Check that the ID passed is a testimonial
			$postTypeOfID = get_post_type( $testimonialIDToFetch );

			if( $postTypeOfID !== 'testimonial' ) {
				return '<!-- A blockquote would be here, but a post ID that isn\'t a testimonial was passed -->';
			}

			// Fetch this post's details, use 'display' as the context to ensure filtering (also default, but just for clarity)
			$cite 		= get_post_field( 'post_title', $postID, 'display' );
			$quote 	= get_post_field( 'post_content', $postID, 'display' );
			$url = get_post_meta( $postID, '_fl_testimonial_select', true );

			// Bail if we have an error
			if( is_wp_error( $cite ) ) {
				return '<!-- A blockquote would be here, but an error with the cite was returned: ' . $cite->get_error_message() .' -->';
			}

			if( is_wp_error( $quote ) ) {
				return '<!-- A blockquote would be here, but an error with the quote was returned: ' . $quote->get_error_message() .' -->';
			}

			// Bail if either field is empty
			if( !isset( $cite ) || empty( $cite ) ) {
				return '<!-- A blockquote would be here, but the cite is empty -->';
			}

			if( !isset( $quote ) || empty( $quote ) ) {
				return '<!-- A blockquote would be here, but the quote is empty -->';
			}

			if( !isset( $url ) || empty( $url ) ) {
				return '<!-- A blockquote would be here, but the quote is empty -->';
			}

			// OK, we're all good. Return the array of details.
			return array(
				'cite' 	=> $cite,
				'quote' => $quote,
				'url' 	=> $url
			);

		}/* checkPostIDIsValidTestimonial() */
		

		/**
		 * Returns the output for a single quote. Pass in the cite and quote and this will return the full HTML with
		 * the <blockquote>, <cite>, <p> etc.
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (string) $cite - The author of the quote
		 * @param (string) $quote - The text of the quote
		 * @return (string) - $markup - The full markup for a single blockquote
		 */
		
		protected function getMarkupForSingleBlockquote( $cite = '', $quote = '', $url = '' ) {

			$pTagClasses = apply_filters( 'ctlt_blockquote_single_blockquote_p_tag_classes', 'text-main' );
			$urlClasses = apply_filters( 'ctlt_blockquote_single_blockquote_p_tag_classes', 'btn pull-right' );

			$markup = '
			<blockquote>
				<p class="' . $pTagClasses . '">&ldquo;' . esc_textarea( $quote ) . '&rdquo;</p>
				<cite>&mdash; ' . esc_html( $cite ) . '</cite>
				<a class="'. $urlClasses .'" href="' . get_permalink( $url ) . '">Read case study ></a>
			</blockquote>
			';

			return apply_filters( 'ctlt_blockquote_single_blockquote', $markup, $quote, $cite );

		}/* getMarkupForSingleBlockquote() */


		/**
		 * Returns the markup for a single blockquote within a slider (i.e. wrapped)
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (string) $cite - The author of the quote
		 * @param (string) $quote - The text of the quote
		 * @return (string) - $markup - The full markup for a single blockquote
		 */
		
		protected function getMarkupForSingleBlockQuoteInSlider( $cite = '', $quote = '', $url = '' ) {

			$markup = '<li>' . $this->getMarkupForSingleBlockquote( $cite, $quote, $url ) . '</li>';

			return apply_filters( 'ctlt_blockquote_single_blockquote_in_slider', $markup, $cite, $quote );

		}/* getMarkupForSingleBlockQuoteInSlider() */



		/**
		 * Register shortcake integration
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param () $ - 
		 * @return () - 
		 */
		
		public function init__registerShortcakeIntegration() {

			if( !function_exists( 'shortcode_ui_register_for_shortcode' ) ) {
				return;
			}

			$this->singleBlockquoteShortcakeRegistration();

			$this->multipleBlockquoteShortcakeRegistration();

		}/* init__registerShortcakeIntegration() */


		/**
		 * Shortcake integration for a single blockquote
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param null
		 * @return null
		 */
		
		protected function singleBlockquoteShortcakeRegistration() {

			// Fetch the options for the dropdown for this. i.e. a list of all testimonials
			// Limiting to 200 just in case, could easily change this
			$allTestimonialsArgs = array(
				'post_type' 			=> 'testimonial',
				'posts_per_page' 		=> 200,
				'no_found_rows' 		=> true, // Don't need pagination
				'update_post_meta_cache' 	=> false, // Helps speed this query up
				'update_post_term_cache' 	=> false, // Also helps speed it up
			);

			// Limit to 100 for now
			$allTestimonials = $this->getTitlesAndContentOfPostsOfPostType( 'testimonial', 100 );

			// convert the array of arrays into just one array with 'id' => 'title'
			$testimonialOptions = array(
				0 => 'Select Quote'
			);

			foreach ( $allTestimonials as $postID => $titleAndContent ) {
				$testimonialOptions[$postID] = $titleAndContent['title'] . ' (' . $postID . ')';
			}

			shortcode_ui_register_for_shortcode(
				'ctlt-blockquote-single',
				array(

					'label' => 'Blockquote Single',
					'listItemImage' => 'dashicons-format-quote',
					'attrs' => array(
						array(
							'label' 		=> 'Testimonial',
							'attr'  			=> 'testimonial',
							'type'  		=> 'select',
							'options'		=> $testimonialOptions
						)
					)
				)
			);

		}/* singleBlockquoteShortcakeRegistration() */

		/**
		 * Shortcake integration for multiple blockquotes
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param null
		 * @return null
		 */
		
		protected function multipleBlockquoteShortcakeRegistration() {

			shortcode_ui_register_for_shortcode(
				'ctlt-blockquote-slider',
				array(

					'label' => 'Blockquote Slider',
					'listItemImage' => 'dashicons-format-chat',
					'attrs' => array(
						array(
							'label' 		=> 'Testimonials',
							'attr'  			=> 'testimonials',
							'type'  		=> 'text',
							'placeholder' 	=> '1,2,3'
						)
					)
				)
			);

		}/* multipleBlockquoteShortcakeRegistration() */
		


		/**
		 * Fetch x-num post titles and content with the specified post type
		 * Does not fetch post meta/tax stuff to speed up query
		 *
		 * @author Richard Tape <@richardtape>
		 * @since 1.0
		 * @param (string) $postType - The post type to fetch 
		 * @param (int) $num - The number of posts to fetch
		 * @return (array) - The titles and content for each post of this post type
		 */
		
		public function getTitlesAndContentOfPostsOfPostType( $postType = false, $num = 100 ) {

			// Default to post
			if( !$postType ) {
				$postType = 'post';
			}

			// Sanitize
			$postType = sanitize_text_field( $postType );
			$num = intval( $num ); // Could be '-1' so can't use absint() (try not to use -1 though)

			// TODO: Check post type exists
			$allPostTypePostsArgs = array(
				'post_type' 			=> $postType,
				'posts_per_page' 		=> $num,
				'no_found_rows' 		=> true, // Don't need pagination
				'update_post_meta_cache' 	=> false, // Helps speed this query up
				'update_post_term_cache' 	=> false, // Also helps speed it up
			);

			$allPostTypePosts = new WP_Query( $allPostTypePostsArgs );

			// Start fresh
			$allPostTypePostsDetails = array();
			
			if( !$allPostTypePosts->have_posts() ) {
				return $allPostTypePostsDetails;
			}

			while ( $allPostTypePosts->have_posts() ) : $allPostTypePosts->the_post();
				
				$title 		= apply_filters( 'the_title', get_the_title() );
				$content 	= apply_filters( 'the_content', get_the_content() );
				$postID 	= get_the_ID();

				$allPostTypePostsDetails[$postID] = array( 'title' => $title, 'content' => $content );

			endwhile;

			wp_reset_postdata();

			return $allPostTypePostsDetails;

		}/* getTitlesAndContentOfPostsOfPostType() */
		


	}/* class CTLT_Blockquote_Shortcode */

	$CTLT_Blockquote_Shortcode = new CTLT_Blockquote_Shortcode();

?>