<?php
/**
 * Archive Template
 *
 * The archive template is basically a placeholder for archives that don't have a template file. 
 * Ideally, all archives would be handled by a more appropriate template according to the current
 * page context.
 *
 *
 */

get_header(); // Loads the header.php template. ?>

	<div id="content" class="hfeed content <?php echo esc_attr( apply_filters( 'ubc_collab_content_class', $content_class, 'archive' ) ); ?>">

		<?php // Hybrid_before_content !
		do_atomic( 'before_content' ); ?>
		<header>
			<h1 class="page-title centered-content">Case Studies</h1>
		</header>
		
		<?php $args = array(
			'post_type'              => 'case-studies',
			// 'category_name'          => 'featured',
			'tax_query' => array(
				array(
					'taxonomy'	=> 'case-studies-categories',
					'field' 	=> 'slug',
					'terms' 	=> 'featured',
				),
			),
			'pagination'             => false,
			'posts_per_page'         => '1',
			'order'                  => 'ASC',
			'orderby'                => 'date',
		);

		// The Query!
		$featured_query = new WP_Query( $args ); ?>

		<?php if ( $featured_query->have_posts() ) : ?>

		<section class="featured-post pos-relative">

		<?php while ( $featured_query->have_posts() ) : $featured_query->the_post();
			$special_excerpt = get_post_meta( get_the_ID(), '_fl_descriptive_excerpt_key', true );
			$fl_descriptive_title_key = esc_attr( get_post_meta( get_the_ID(), '_fl_descriptive_title_key', true ) );

			if ( ! empty( $fl_descriptive_title_key ) ) :

				$fl_page_title = $fl_descriptive_title_key;

			else :

				$fl_page_title = get_the_title();

			endif;
		?>

			<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php the_post_thumbnail( 'default_featured_image' ); ?></a>
			<div class="featured-case-study pos-absolute bg-second">
				<h3 class="featured-child-page-title h2"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php echo esc_html( $fl_page_title );  ?></a></h3>
				<?php if ( ! empty( $special_excerpt ) ) :

					echo '<p>'. esc_html( $special_excerpt ) .'</p>';

					else : the_excerpt();

					endif;

				?>
				<p><a class="btn" title="<?php the_title_attribute( array( 'before' => 'More on: ', 'after' => '' ) ); ?>" href="<?php the_permalink(); ?>">Read more ></a> <a class="btn btn-primary sc-text-anchor" href="#cs-search" title="See A list of all Case Studies">All case studies <i class="icon-angle-down"></i></a></p>
			</div>

		<?php endwhile;

		wp_reset_postdata();

		else : echo '<div class="centered-content">Sorry no featured Case Studies. :(</div>';

		endif;

		?>

		</section>

		<section id="cs-search" class="case-studies-search-box">
			<form method="get" id="searchform" action="<?php bloginfo( 'home' ); ?>/" class="form-search centered-content text-center">
				<div>
					<label for="searchfield"><h3><i class="icon-search txt-fourth" aria-hidden="true" title="Search Case Studies"></i> Case Studies</h3></label>
					<input id="searchfield" type="text" size="18" value="<?php echo esc_attr( wp_specialchars( $s, 1 ) ); ?>" name="s" id="s" class="search-query" placeholder="Start your search here..."><button type="submit" id="searchsubmit" class="btn btn-primary btn-large">Search</button>
				</div>
			</form>
		</section>

		<?php $args = array(
			'post_type'              => 'case-studies',
			'pagination'             => true,
			'posts_per_page'         => '20',
			'order'                  => 'DESC',
			'orderby'                => 'date',
			'tax_query' => array(
					'relation' => 'AND',
					array(
						'taxonomy'	=> 'case-studies-categories',
						'field' 	=> 'slug',
						'terms' 	=> 'featured',
						'operator'	=>	'NOT IN',
					),
				),
		);

		// The Query !
		$main_query = new WP_Query( $args ); ?>

		<?php if ( $main_query->have_posts() ) : ?>	
		<section id="case-study-top" class="showcase case-study archive centered-content">
   		<?php while ( $main_query->have_posts() ) : $main_query->the_post();

			$special_excerpt = get_post_meta( get_the_ID(), '_fl_descriptive_excerpt_key', true );
			$fl_descriptive_title_key = esc_attr( get_post_meta( get_the_ID(), '_fl_descriptive_title_key', true ) );
			$the_time_format			= 'Y-m-d';
			$get_the_date 				= get_the_date();
			$screen_reader_date			= get_the_date( $the_time_format );

			if ( ! empty( $fl_descriptive_title_key ) ) :

				$fl_page_title = $fl_descriptive_title_key;

			else :

				$fl_page_title = get_the_title();

		endif;

		?>
			<article>
				<div id="child-<?php the_ID(); ?>" class="row-fluid child-page">
					<div class="span4">
						<a class="child-img-link" href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php the_post_thumbnail( 'default_featured_image_child_thumbs' ); ?></a>
					</div><!-- end span4 -->
					<div class="span8">
						<header>
							<h3 class="child-page-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php echo esc_html( $fl_page_title ); ?></a></h3>
							<p><small>Posted on <time datetime="<?php echo esc_attr( $screen_reader_date	); ?>"><?php echo esc_html( $get_the_date ); ?></time></small></p>
						</header>
						<?php if ( ! empty( $special_excerpt ) ) :

							echo '<p>'. esc_html( $special_excerpt ) .'</p>';

						else :

							the_excerpt();

						endif;

						?>
						<p><a class="btn" title="<?php the_title_attribute( array( 'before' => 'More on ', 'after' => '' ) ); ?>" href="<?php the_permalink(); ?>">Read more ></a></p>
					</div><!-- end span8 -->
				</div><!-- end row-fluid -->
			</article><!-- end parent id -->
		<hr>
   		<?php endwhile;

			wp_reset_postdata();

		?>
		</section>

		<?php

			else : echo 'Sorry no Case Studies at this time. :(';

		endif; ?>
			
		<?php do_atomic( 'after_content' ); // hybrid_after_content ?>

	</div><!-- .content .hfeed -->

<?php get_footer(); // Loads the footer.php template. ?>
