<?php
/**
 * Singular Template
 *
 * WordPress currently supports custom post types displayed on the singular post level. This template
 * is a catchall template for the singular views of these posts. It should only be used as a backup or if
 * your custom post type doesn't require a custom structure. The template hierarchy for singular views
 * of post types is like so: $post_type-$template.php, $post_type-$slug.php, $post_type-$id.php,
 * $post_type.php, and singular.php.
 *
 *
 */

get_header(); // Loads the header.php template. ?>

	<div id="content" class="hfeed content">		
		<?php do_atomic( 'before_content' ); ?>
		
		<?php if ( have_posts() ) : while ( have_posts() ) : the_post();

				$home_intro_message = get_post_meta( get_the_ID(), 'home_intro_message', true );
				$six_pillars_section_title = esc_attr( get_post_meta( get_the_ID(), 'six_pillars_section_title', true ) );
				$six_pillars_section_intro = esc_attr( get_post_meta( get_the_ID(), 'six_pillars_section_intro', true ) );

		?>

			<div id="post-<?php the_ID(); ?>" class="<?php hybrid_entry_class(); ?>">

				<div class="hidden"><?php do_atomic( 'before_entry' ); ?></div>

				<div class="entry-content">
					
					<div class="homepage-sections"> 
						<div id="homeslide-0" class="fixed-region">
						    <div id="intro-slide" class="fixed-area homepage-section home-intro">
								<div class="bound height-100">
									<div class="intro-block ">
										<div class="ubc-building dontRead">UBC CTLT Building.</div>
										<div class="yellow-bars-container dontRead"><div class="wifi-bars-css yellow-bars dontRead">Yellow WIFI signal bars.</div></div>
										<div class="walking-man-container dontRead"><div class="walking-man dontRead">A student walking down one of UBC's sidewalks while reading phone.</div></div>
										<div class="wifi-bars-css dark-blue-bars dontRead">Blue WIFI signal bars.</div>
										<div class="wifi-bars-css blue-bars dontRead">Dark blue WIFI signal bars.</div>
										<div class="people-bench dontRead">Two faculty members on a bench using a tablet</div>
										<div class="man-tree-bike dontRead">a student or faculty member sitting under a tree with a bike.</div>
										<div class="intro-txt centered-content centered-content-absolute">
											<?php if ( ! empty( $home_intro_message ) ) : ?>

												<?php echo wp_kses_post( $home_intro_message ); ?>

											<?php else : ?>

											<h2 class="bg-pillar-five">What is Flexible Learning?</h2>
											<h3>For instructors:</h3>
											<p>It means using evidence-based, technology-rich teaching methods to improve student learning and engagement.</p>
											<h3>For students:</h3>
											<p>It means more choice, access and success.</p>
											<h3>For UBC:</h3>
											<p>It’s a strategic priority.</p>

										<?php endif; ?>

										</div><!-- end .intro-txt -->

										<a href="#homeslide-1" class="scroll-link" title="next slide"><span class="arrow-down"><i class="icon-4x icon-angle-down"></i></span></a>
									</div><!-- end .intro-block -->
								</div><!-- end .bound -->
							</div><!-- end #intro-slide -->

						</div><!-- end .fixed-region -->

						<div class="fixed-region">
						    <div id="homeslide-1" class="fixed-area bg-home-pillar-section homepage-section ">
								<div  class="centered-content-pillars">
									<div class="bound height-100">

									<h2 class="bg-fourth centered-content">
									<?php if ( ! empty( $six_pillars_section_title ) ) : echo esc_html( $six_pillars_section_title );

									else : echo 'Please add the custom field with a name of six_pillars_section_title.';

									endif;?></h2>
									
									<?php if ( ! empty( $six_pillars_section_intro ) ) :

										echo '<p class="lead centered-content">'. esc_html( $six_pillars_section_intro ) .'</p>';

									endif; ?>

									<ul class="grid cs-style-1">

									<?php $args = array(
									    'post_type'      => 'page',
									    'posts_per_page' => 6,
									    'order'          => 'ASC',
									    'orderby'        => 'menu_order',
									    'post_parent'	 => '181', // Live site
									    //'post_parent'	 => '445',
									    // 'post_parent__in' => array( 181, 445 ),
								 	);

								 	$sixPillars = new WP_Query( $args );

								 	if ( $sixPillars->have_posts() ) :

										while ( $sixPillars->have_posts() ) : $sixPillars->the_post();

											$section_color_pillar = get_post_meta( get_the_ID(), 'section_colour', true );
											$section_url = get_post_meta( get_the_ID(), 'section_image_url', true );
											$special_excerpt = get_post_meta( get_the_ID(), '_fl_descriptive_excerpt_key', true );

								 	?>
										<li>
											<figure class="<?php echo esc_attr( $section_color_pillar ); ?> section-<?php echo($post->post_name); ?> hideme">
											<a href="<?php the_permalink() ?>" class="featured-pillar-img" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php if( ! empty( $section_url ) ): ?> <img src="<?php echo esc_attr( $section_url ); ?>" alt="<?php echo the_title_attribute(); ?>" /></a>
											<?php else: echo '<p><small>No image provided. Please use or create a custom field named "section_image_url" and provide the image url.</small></p>'; 
												 endif;

												 if( !$section_color_pillar ): echo '<p><small> No section color provided. Please use or create a custom field named "section_color" and provide the class name.</small></p>';
												 	endif;
											?> 
											<p class="h4 hidden-phone dontRead"><?php the_title() ?></p>
												<figcaption class="txt-main">
													<h3 class="h4 txt-main"><a href="<?php the_permalink() ?>" class="pillar-title" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>"><?php the_title() ?></a></h3>
													<div class="home-pillars-excerpt">
													<?php if ( ! empty( $special_excerpt ) ) :

														echo '<p>'. esc_html( $special_excerpt ) .'</p>';

													else : the_excerpt();

													endif;

													?>
													</div>
													<a href="<?php the_permalink() ?>" class="btn btn-small" title="<?php the_title_attribute( array( 'before' => 'See More on: ', 'after' => '' ) ); ?>">Read more ></a>
													<?php if ( current_user_can( 'manage_options' ) ) : ?>
													<a href="<?php echo get_edit_post_link(); ?>" class="btn btn-mini edit-btn" title="Edit this post"><i class="icon-edit"></i>  edit page</a>
													<?php endif; ?>
												</figcaption>
											</figure>
										</li>
									<?php

										endwhile;

										else : echo '<div class="centered-content"><div class="alert alert-fl well"><h3>The 6 pillars are missing!</h3><img src="http://flexible-learning2015.sites.olt.ubc.ca/files/2015/03/404-missing.gif" width="350px"><p><i class="icon-exclamation-sign"></i> Please go to <a href="wp-admin/themes.php?page=theme_options">theme options</a> and select the 6 pillars parent page.</p></div></div>';

										endif;

										wp_reset_postdata();

									?>

									</ul><!-- end .grid.cs-style-1 -->
									<div class="text-center centered-content cta"><p><a href="our-approach" class="btn" title="See our approach">See our approach ></a></p></div>
									<a href="#homeslide-2" title="next slide" class="scroll-link"><span class="arrow-down"><i class="txt-main icon-4x icon-angle-down"></i></span></a>
									</div><!-- .bound.height-100 -->
								</div><!-- .centered-content -->
						    </div><!-- end parent id -->
					    </div><!-- .fixed-region -->

					<?php

					// Child Pages Query

					//$fl_descriptive_title_key = get_post_meta( get_the_ID(), '_fl_descriptive_title_key', true);

					$args = array(
					    'post_type'      => 'post',
					    'posts_per_page' => 5,
					    'category_name'	 => 'Homepage Sections',
					    'order'          => 'ASC',
					    'orderby'        => 'meta_value_num',
					    'meta_key'		 => 'section_order'
					 );


					$homePage_section = new WP_Query( $args );
					$n = 1;
					$nn = 2;
					if ( $homePage_section->have_posts() ) :

						while ( $homePage_section->have_posts() ) : $homePage_section->the_post();

						    $section_color = get_post_meta( get_the_ID(), 'section_colour', true );
						    $n++;
						    $nn++;
					    ?>

						    <div class="fixed-region">
						        <div class="fixed-area <?php echo esc_attr( $section_color ); ?> homepage-section section-<?php echo( $post->post_name ); ?>">
									<div id="homeslide-<?php echo $n; ?>" class="centered-content">
										<div class="bound height-100">
											<?php the_content(); ?>
											<?php if ( current_user_can( 'manage_options' ) ) : ?>
											<a href="<?php echo get_edit_post_link(); ?>" class="btn btn-small edit-btn" title="Edit this post"><i class="icon-edit"></i>  edit section <i class="icon-angle-right"></i></a>
											<?php endif; ?>
											<a href="#homeslide-<?php echo $nn; ?>" class="scroll-link" title="next slide"><span class="arrow-down center-align"><i class="icon-4x icon-angle-down txt-main"></i></span></a>
										</div><!-- .bound.height-100 -->
									</div><!-- .centered-content -->
						        </div><!-- end parent id -->
					    </div><!-- .fixed-region -->

					    <?php endwhile; ?>
					<?php

					else : echo '<div class="centered-content"><div class="alert alert-fl well"><h2>The other sections</h2><h3>Sorry, there are no sections to show!</h3><img src="http://flexible-learning2015.sites.olt.ubc.ca/files/2015/03/404-missing.gif" width="350px"><p><i class="icon-exclamation-sign"></i> Create a post with the category name "<strong>Homepage Sections</strong>" and a custom field with a name of "<strong>section_order</strong>".</p></div></div>';

					endif;

					wp_reset_postdata(); ?>

					<?php wp_link_pages( array( 'before' => '<p class="page-links pages">' . __( 'Pages:', 'hybrid' ), 'after' => '</p>' ) ); ?>
				</div><!-- .entry-content -->

				<?php do_atomic( 'after_entry' ); ?>

				</div><!-- .homepage-sections -->
			
			</div><!-- .hentry -->

			<?php do_atomic( 'after_singular' ); ?>

			<?php comments_template( '/comments.php', true ); ?>

			<?php endwhile; ?>

		<?php else : ?>

			<?php get_template_part( 'loop-error' ); // Loads the loop-error.php template. ?>

		<?php endif; ?>

		<?php do_atomic( 'after_content' ); ?>

	</div><!-- .content .hfeed -->

<?php get_footer(); ?>
