<?php
/**
 * Singular Template
 *
 * WordPress currently supports custom post types displayed on the singular post level. This template
 * is a catchall template for the singular views of these posts. It should only be used as a backup or if
 * your custom post type doesn't require a custom structure. The template hierarchy for singular views
 * of post types is like so: $post_type-$template.php, $post_type-$slug.php, $post_type-$id.php,
 * $post_type.php, and singular.php.
 *
 *
 */

get_header(); // Loads the header.php template. ?>

	<div id="content" class="hfeed content centered-content">		
		<?php do_atomic( 'before_content' ); ?>
		
		<?php if ( have_posts() ) : while ( have_posts() ) : the_post(); ?>

			<div id="post-<?php the_ID(); ?>" class="<?php hybrid_entry_class(); ?>">

				<header>
					<?php do_atomic( 'before_entry' ); ?>
				</header>

				<?php if ( has_post_thumbnail() ) :

					the_post_thumbnail( 'default_featured_image', array( 'class' => 'featured-images featured-images-pages text-center-block' ) );

				endif; ?>

				<div class="entry-content">

					<?php the_content(); ?>

					<?php $args = array(
					    'post_type'      => 'page',
					    'posts_per_page' => -1,
					    'post_parent'    => $post->ID,
					    'order'          => 'ASC',
					    'orderby'        => 'menu_order',
					 );


					$parent = new WP_Query( $args );

					if ( $parent->have_posts() ) : ?>

						<div class="parents-children-group"> 
					    <?php while ( $parent->have_posts() ) : $parent->the_post();

					    	$fl_descriptive_title_key = esc_attr( get_post_meta( get_the_ID(), '_fl_descriptive_title_key', true ) );

					    	if ( ! empty( $fl_descriptive_title_key ) ) :

								$fl_page_title = $fl_descriptive_title_key;

							else :

								$fl_page_title = get_the_title();

							endif;

					    ?>

					        <article id="child-<?php the_ID(); ?>" class="child-page">

								<div class="row-fluid">

									<?php if ( has_post_thumbnail() ) : ?>

									<div class="span4">
										<a class="child-img-link" href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on ', 'after' => '' ) ); ?>"><?php the_post_thumbnail( 'default_featured_image_child_thumbs' ); ?></a>
									</div><!-- end span4 -->
									<div class="span8">
										<header>
											<h3 class="child-page-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on ', 'after' => '' ) ); ?>"><?php echo $fl_page_title; ?></a></h3>
										</header>
										<?php the_excerpt(); ?>
										<p><a class="btn" href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'More on ', 'after' => '' ) ); ?>">Read more ></a></p>
									</div><!-- end span8 -->

								<?php else : ?>

									<div class="span8">
										<header>
											<h3 class="child-page-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'See More on ', 'after' => '' ) ); ?>"><?php echo esc_html( $fl_page_title ); ?></a></h3>
										</header>
										<?php the_excerpt(); ?>
										<p><a class="btn" href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array( 'before' => 'More on ', 'after' => '' ) ); ?> ">Read more ></a></p>
									</div><!-- end span8 -->

								<?php endif; ?>

								</div><!-- end row-fluid -->

					        </article><!-- end parent id -->
							<hr>
					    <?php endwhile; ?>
					   </div>

					<?php endif; ?>

					<?php wp_reset_postdata(); ?>

					<?php wp_link_pages( array( 'before' => '<p class="page-links pages">' . __( 'Pages:', 'hybrid' ), 'after' => '</p>' ) ); ?>
				</div><!-- .entry-content -->

				<?php do_atomic( 'after_entry' ); ?>

			</div><!-- .hentry -->

			<?php do_atomic( 'after_singular' ); ?>

			<?php comments_template( '/comments.php', true ); ?>

			<?php endwhile; ?>

		<?php else : ?>

			<?php get_template_part( 'loop-error' ); ?>

		<?php endif; ?>

		<?php do_atomic( 'after_content' ); ?>

	</div><!-- .content .hfeed -->

<?php get_footer(); ?>
