<?php
/**
 * Singular Template
 *
 * WordPress currently supports custom post types displayed on the singular post level. This template
 * is a catchall template for the singular views of these posts. It should only be used as a backup or if
 * your custom post type doesn't require a custom structure. The template hierarchy for singular views
 * of post types is like so: $post_type-$template.php, $post_type-$slug.php, $post_type-$id.php,
 * $post_type.php, and singular.php.
 *
 *
 */

get_header(); // Loads the header.php template.

$newsCategoriesSlugOutput = '';
?>

	<div id="content" class="hfeed content centered-content">

		<?php do_atomic( 'before_content' ); ?>

		<?php if ( have_posts() ) : while ( have_posts() ) : the_post();

				// Outputs terms slug to help style the post by type!
				$terms = get_the_terms( $post->ID, 'categories' );

				if ( $terms && ! is_wp_error( $terms ) ) :

					$newsCategoriesSlug = array();

					foreach ( $terms as $term ) {

						$newsCategoriesSlug[] = $term->slug;

					}

					$newsCategoriesSlugOutput = join( ' ', $newsCategoriesSlug );

		 endif; ?>

			<div id="post-<?php the_ID(); ?>" class="<?php echo esc_attr( $newsCategoriesSlugOutput ); ?>">

				<header>
					<?php do_atomic( 'before_entry' ); ?>
				</header>

				<?php if ( has_post_thumbnail() ) :

					the_post_thumbnail( 'default_featured_image', array( 'class' => 'featured-images text-center-block featured-images-pages' ) );

				endif; ?>
				<div class="row-fluid">

				<div id="primary-secondary" class="sidebar aside span3">

					<div id="primary">

						<?php if ( is_active_sidebar( 'primary' ) ) : ?>

						<?php do_atomic( 'before_primary' ); ?>

						<?php dynamic_sidebar( 'primary' ); ?>

						<?php do_atomic( 'after_primary' ); ?>

						<?php endif; ?>

					</div><!-- #primary -->

					<?php if ( is_active_sidebar( 'secondary' ) ) : ?>
					<div id="secondary">

						<?php do_atomic( 'before_secondary' ); ?>

						<?php dynamic_sidebar( 'secondary' ); ?>

						<?php do_atomic( 'after_secondary' ); ?>

					</div><!-- #secondary -->
					<?php endif; ?>

				</div><!-- #primary-secondary .aside -->

				<div class="entry-content span9">

					<p class="fl-author">

						<?php

						$theTime = get_the_time( 'F jS, Y' );

						switch ( $newsCategoriesSlugOutput ) {

							case 'flexibytes':

								echo '<small>Posted on <span class="date">';
								echo esc_html( $theTime );
								echo '</span></small>';

								break;

							default: ?>

								<small>By  <span class="name"><?php if ( function_exists( 'coauthors' ) ) {

							    	coauthors();

								} else {

								    the_author_posts_link();

								} ?></span> posted on <span class="date"><?php echo esc_html( $theTime ); ?></span></small>

								<?php break;

						} ?>

					</p>

					<?php do_action( 'social_media_buttons' ); ?>

					<?php the_content(); ?>

					<?php wp_link_pages( array( 'before' => '<p class="page-links pages">' . __( 'Pages:', 'hybrid' ), 'after' => '</p>' ) ); ?>
				</div><!-- .entry-content -->
			</div><!-- end .row-fluid -->

				<?php do_atomic( 'after_entry' ); ?>

			</div><!-- .hentry -->

			<?php do_atomic( 'after_singular' ); ?>

			<div class="row-fluid">

				<div class="span9 offset1">

					<?php comments_template( '/comments.php', true ); ?>

				</div><!-- .span9 -->

			</div><!-- .row-fluid-->

			<?php endwhile; ?>

		<?php else : ?>

			<?php get_template_part( 'loop-error' ); // Loads the loop-error.php template. ?>

		<?php endif; ?>

		<?php do_atomic( 'after_content' ); ?>

	</div><!-- .content .hfeed -->

<?php get_footer(); ?>
