<?php
/**
 * Plugin Name: CTLT Flexible Learning Website.
 * Plugin URI: http://ctlt.ubc.ca
 * Description: Custom Post Types, Taxomomies, Page Templates, Custom HomePage.
 * Version: 1.1.6
 * Author: David Brabbins
 * Author URI: http://ctlt.ubc.ca
 * License: A short license name. Example: GPL2
 */

if ( ! defined( 'ABSPATH' )  ) {
	return;
}

	/**
	 * Include plugin files
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param $post_id
	 * @return null
	*/


define( 'CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );

require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/theme-options.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/page-templates.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/custom-post-types.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/custom-post-types-templates.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/custom-taxonomies.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/meta-boxes.php';
require_once CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/shortcodes.php';

class CTLT_Flexible_Learning_Website {

	/**
	 * Construct
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param null
	 * @return null
	*/

	public function setupActionsAndFilters() {

		add_action( 'init', array( $this, 'default_featured_image_size' ), true );

		// enqueue they scripts and styles
		add_action( 'wp_enqueue_scripts', array( $this, 'flexible_learning_scripts' ), 1 );

		//do action upcoming events
		add_action( 'upcoming_events', array( $this, 'events_wp_query_upcoming' ), 10, 2 );

		//do action past events
		add_action( 'past_events', array( $this, 'events_wp_query_past' ), 10, 2 );

		//Custom title for testimonials title field
		add_filter( 'gettext', array( $this, 'custom_enter_title_for_testomonials' ) );

		add_filter( 'image_size_names_choose', array( $this, 'admin_featured_image_size' ) );

		//Social media share buttons for custom post type == news
		add_action( 'social_media_buttons', array( $this, 'social_sharing_buttons' ), 10, 2 );
	}

	/**
	 * Enqueue Scripts and styles
	 *
	 * @author David Brabbins
	 * @since 1.0.3
	 * @param null
	 * @return null
	 */

	public function flexible_learning_scripts() {
		// Register and enqueue scripts
		wp_register_script( 'home_page_js',  plugin_dir_url( __FILE__ ) . 'assets/js/home-page-min.js', array( 'jquery' ), '1.0', true );

		wp_register_script( 'flexible-learning-js',  plugin_dir_url( __FILE__ ) . 'assets/js/flexible-learning-js.js', array( 'jquery' ), '1.0', true );


		if ( is_front_page() || is_home() ) :

			wp_enqueue_script( 'home_page_js' );

		endif;

		wp_enqueue_script( 'flexible-learning-js' );

		// Register and enqueue styles
		wp_register_style( 'fl_stylesheet',  plugin_dir_url( __FILE__ ) . 'assets/css/fl-stylesheet.css', false, '0.1', 'all' );
		wp_register_style( 'whitney_font', '//cloud.typography.com/6804272/781004/css/fonts.css', false, false, 'all' );

		wp_enqueue_style( 'whitney_font' );
		wp_enqueue_style( 'fl_stylesheet', '1.0' );

	}


	/**
	 * Removes Layout options for pages
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param null
	 * @return null
	*/

	public function admin_menu__removePageLayoutBox() {

		remove_meta_box( 'layout_box', 'page', 'side' );

	}

	/**
	 * Adds Custom Title Field to custom post type Testimonials
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param global $post_type $input
	 * @return $input
	 */

	public function custom_enter_title_for_testomonials( $input ) {

		global $post_type;

		if ( is_admin() && 'Testimonial Title' == $input && 'testimonial' == $post_type ) {
			return 'Enter First Name and Last Name';
		}

		return $input;
	}

	public function default_featured_image_size() {

		add_image_size( 'default_featured_image', 1200, 595, true );
		add_image_size( 'default_featured_image_child_thumbs', 960, 601, true );

	}

	public function admin_featured_image_size( $sizes ) {

		return array_merge( $sizes, array(
			'default_featured_image' => __( 'Flexible Learning Featured Image' ),
		) );

	}

	/**
	 * Helper method to fetch the news + events landing page categories that are checked in the theme options
	 * Returns an associative array where the keys are the term slugs and the value is the term name
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param null
	 * @return (array|false) - List of events categories chosen to show in the events landing page, false if none
	 */

	public static function getNewsEventsLandingPageCats() {

		// Start fresh!
		$categoriesToShow = array();

		// This is our custom taxonomy!
		$terms = get_terms( 'categories' );

		if ( ! $terms || is_wp_error( $terms ) || ! is_array( $terms ) || empty( $terms ) ) {
			return $categoriesToShow;
		}

		// Create new array to store term slug for ordering!
		$usableTerms = array();

		foreach ( $terms as $key => $termObject ) {
			$usableTerms[ $termObject->slug ] = $termObject->name;
		}
		arsort( $usableTerms );

		foreach ( $usableTerms as $termSlug => $termName ) {

			// If it's saved/checked in the theme options, add to our array!
			if ( UBC_Collab_Theme_Options::get( 'news-event-terms-' . $termSlug ) == '1' ) {

				$categoriesToShow[ $termSlug ] = $termName;

			}
		}

		return $categoriesToShow;

	}
	/* getNewsEventsLandingPageCats() */


	/**
	 * Method to allow including of a template part from within a plugin. Replicates what locate_template() does in
	 * WordPress core, but allows you to specify the path where to start looking. Falls back to looking in the
	 *
	 *
	 * @since 0.1
	 *
	 * @param string $startPath The path - probably set via a constant - of where to start looking
	 * @param string|array $templateNames Template file(s) to search for, in order.
	 * @param bool $load If true the template file will be loaded if it is found.
	 * @param bool $requireOnce Whether to require_once or require. Default true. Has no effect if $load is false.
	 * @return string The template filename if one is located.
	 */

	public static function locateTemplateInPlugin( $startPath, $templateNames, $load = false, $require_once = true ) {

		$located = '';

		foreach ( (array) $templateNames as $templateName ) {

			if ( ! $templateName ) {
				continue;
			}

			if ( file_exists( untrailingslashit( $startPath ) . '/' . $templateName ) ) {

				$located = untrailingslashit( $startPath ) . '/' . $templateName;

				break;

			}

			else if ( file_exists( untrailingslashit( STYLESHEETPATH ) . '/' . $templateName ) ) {
				$located = untrailingslashit( STYLESHEETPATH ) . '/' . $templateName;

				break;
			}

			else if ( file_exists( untrailingslashit( TEMPLATEPATH ) . '/' . $templateName ) ) {

				$located = untrailingslashit( TEMPLATEPATH ) . '/' . $templateName;

				break;

			}

		}

		if ( $load && '' != $located ) {
			load_template( $located, $require_once );
		}

		return $located;

	}/* locateTemplateInPlugin() */


	/**
	 * Fetch the 1 featured post in the news post type
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param () $
	 * @return () -
	 */

	public static function displayNewsFeaturedPost() {

		$args = array(
			'post_type'              => 'news',
			'tax_query' => array(
				array(
					'taxonomy' => 'categories',
					'field' => 'slug',
					'terms' => 'featured-post',
				),
			),
			'pagination'             => false,
			'posts_per_page'         => '1',
			'order'                  => 'ASC',
			'orderby'                => 'date',
		);

		$featured_query = new WP_Query( $args );

		if ( ! $featured_query->have_posts() ) {
			echo '<div class="centered-content">Sorry, we could not find a featured post :(</div>';
			return;
		}

		while ( $featured_query->have_posts() ) : $featured_query->the_post();

			if ( ! has_post_thumbnail( get_the_ID() ) ) {
				echo '<div class="centered-content">Sorry, your featured post does not contain a featured image :(</div>';
				return;
			}

			static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'stories-news-archive-featured-post.php', true );

		endwhile;

		wp_reset_postdata();

	}/*  displayNewsFeaturedPost()*/


	/**
	 * Get the markup for the posts on the news/events archive page.  Which ones shown is dependent on a theme options
	 * The markup is a set of tabs, each of which contain a list of posts
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param null
	 * @return null
	 */

	public static function displayNewsEventsTabsAndPosts() {

		// If there's no categories chosen, we just show a message to that effect
		$categoriesToShow = static::getNewsEventsLandingPageCats();

		if ( ! $categoriesToShow || ! is_array( $categoriesToShow ) || empty( $categoriesToShow ) ) {
			echo '<div class="no-categories-to-show"><p>No categories to show</p></div>';
			return;
		}

		// First we output the tabs. We don't need to do a WP Loop for this as it's just some markup
		echo '<ul class="nav nav-tabs" role="tablist" id="myTab">';
		foreach ( $categoriesToShow as $slug => $name ) {

				// Need access to variables so use include()
				include( static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'stories-news-categories-tab-singular.php', false ) );

		}

		echo '</ul>';

		// Now we output the content for each of these tabs.
		echo '<div class="tab-content">';

		foreach ( $categoriesToShow as $slug => $name ) {

				$howManyToShow = 5;

				$args = array(
					'post_type' => 'news',
					'tax_query' => array(
						array(
							'taxonomy' => 'categories',
							'field' => 'slug',
							'terms' => $slug,

						),

					),
					'pagination'             => false,
					'posts_per_page'         => $howManyToShow,
					'order'                  => 'DESC',
					'orderby'                => 'date',
				);

				$thisQuery = new WP_Query( $args );

				if ( ! $thisQuery->have_posts() ) {
					echo 'Sorry, nothing to report :(';
					continue;
				}

				echo '<div role="tabpanel" class="tab-pane active" id="' . esc_attr( $slug ). '">';

				// Add Read more for each tab
				while ( $thisQuery->have_posts() ) : $thisQuery->the_post();

					include( static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'stories-news-categories-post-singular.php', false ) );

				endwhile;

				wp_reset_postdata();

				$btnClass = 'btn-primary';

				switch ( $name ) {
					case 'News':
						echo '<p><a href="/fl-news-and-views/" class="btn '. esc_attr( $btnClass ) .'"> See all '. esc_attr( $name ) .' > </a></p>';
						break;

					case 'Flexibytes':
						echo '<p><a href="/fl-news-and-views/flexibytes/" class="btn '. esc_attr( $btnClass ) .'"> See all '. esc_attr( $name ) .' > </a> <a class="btn btn-inverse" href="/fl-news-and-views/flexibytes/flexibytes-subscription/">Sign up for Flexibytes &gt;</a> </p>';
						break;

					case 'Digital Learning Blog':
						echo '<p><a href="/fl-news-and-views/digital-learning-blog/" class="btn '. esc_attr( $btnClass ) .'"> See all '. esc_attr( $name ) .' posts > </a></p>';

					default:
						break;

				}

				echo '</div>';

		}

		echo '</div>';

	}/* displayNewsEventsTabsAndPosts() */

	/**
	 * Show social media share buttons for custom post type == news
	 *
	 * @author David Brabbins
	 * @since 1.0.6
	 * @param () $content
	 * @return () Social media icons and links
	 */

	public function social_sharing_buttons() {

		//Only show if news cpt or else just the content

		$post_types = 'news';

		if ( $post_types  == get_post_type() && ! is_post_type_archive( $post_types ) ) :

		 // Get current page URL
		 $social_post_url = get_permalink();

		 // Get current page title replace wp space subsitute with an actuall space (should it happen)
		 $social_post_title = str_replace( ' ', '%20', get_the_title() );

		 // Construct sharing URL without using any script
		 $twitterURL = '//twitter.com/intent/tweet?text='.$social_post_title.'&amp;url='.$social_post_url.'&amp;via=UBCFlexibleLearning';
		 $facebookURL = '//www.facebook.com/sharer/sharer.php?u='.$social_post_url;

		 //Social Media icons
		 $twitter_icon = '<i class="icon-twitter"></i> Tweet';
		 $facebook_icon = '<i class="icon-facebook-sign"></i> Share';

			include( static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'share-social-media.php', false ) );

		endif;

	} // social_sharing_buttons()

	/**
	 * Template and query for events archive
	 *
	 * @author David Brabbins
	 * @since 1.0.6
	 * @return () null
	 */

	public function events_wp_query_upcoming () {

		$todayDate = current_time( 'timestamp' );

		//We need to show more posts if on an archive page so lets do that, but if we are not on an archive then we need to show 5
		if ( is_post_type_archive( 'events' ) ) :

			$post_per_page = '-1';

		else :

			$post_per_page = '10';

		endif;

		$args = array(
			'post_type'              => 'events',
			'pagination'             => false,
			'posts_per_page'         => $post_per_page,
			'order'                  => 'ASC',
			'orderby'                => 'meta_value_num',
			'meta_key'				 => '_fl_hidden_end_date_meta_value_key',
			'meta_query' 			 => array(
				array(
					'key' 	  => '_fl_hidden_end_date_meta_value_key',
					'value'	  => $todayDate,
					'compare' => '>=',
				),
			)
		);

		// The Query !
		$main_events_query = new WP_Query( $args );

		if ( $main_events_query->have_posts() ) :

		while( $main_events_query->have_posts() ) : $main_events_query->the_post();

			$eventDate = get_post_meta( get_the_ID(), '_fl_end_date_meta_value_key', true );
			$eventStartDate = get_post_meta( $post->ID, '_fl_start_date_meta_value_key', true );
			$eventTime = get_post_meta( get_the_ID(), '_fl_event_time_meta_value_key', true );
			$eventUrl = get_post_meta( get_the_ID(), '_fl_event_link_meta_value_key', true );

			include( static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'upcoming_events.php', false ) );

		endwhile;

		wp_reset_postdata();

		else:  echo "Sorry, no new events to report :(";

		endif;

	}//events_wp_query_upcoming()

	public function events_wp_query_past () {

		$todayDate = current_time( 'timestamp' );

			$post_per_page = '-1';

		$args = array(
			'post_type'              => 'events',
			'posts_per_page'         => $post_per_page,
			'order'                  => 'ASC',
			'orderby'                => 'meta_value_num',
			'meta_key'				 => '_fl_hidden_end_date_meta_value_key',
			'meta_query' 			 => array(
				array(
					'key' 	  => '_fl_hidden_end_date_meta_value_key',
					'value'	  => $todayDate,
					'compare' => '<=',
				),
			)
		);

		// The Query
		$main_events_query = new WP_Query( $args );

		if ( $main_events_query->have_posts() ) :

		while( $main_events_query->have_posts() ) : $main_events_query->the_post();

			$eventDate = get_post_meta( get_the_ID(), '_fl_end_date_meta_value_key', true );
			$eventStartDate = get_post_meta( $post->ID, '_fl_start_date_meta_value_key', true );
			$eventTime = get_post_meta( get_the_ID(), '_fl_event_time_meta_value_key', true );
			$eventUrl = get_post_meta( get_the_ID(), '_fl_event_link_meta_value_key', true );

			include( static::locateTemplateInPlugin( CTLT_FLW_PLUGIN_PLUGIN_DIR_PATH . '/assets/templates/parts', 'upcoming_events.php', false ) );

		endwhile;

		wp_reset_postdata();

		else:  echo "Sorry, no new events to report :(";

		endif;

	}
	// events_wp_query_past()

}
// class::CTLT_Flexible_Learning_Website

add_action( 'plugins_loaded', 'plugins_loaded__instantiateCTLTObject', 10 );

function plugins_loaded__instantiateCTLTObject() {
	$CTLTObject = new CTLT_Flexible_Learning_Website();
	$CTLTObject->setupActionsAndFilters();
}
