<?php
if ( ! defined( 'ABSPATH' ) ) {
	return;
}

class CTLT_Flexible_Learning_Custom_Metaboxes {

	var $fields = array();

	public function __construct() {

		add_action( 'admin_print_styles', array( $this, 'meta_boxes_admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'custom_post_type_event_scripts' ) );

		add_action( 'add_meta_boxes', array( $this, 'add_descriptive_titles_pages_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'verify_nonce_and_update_descriptive_meta_box' ) );

		add_action( 'add_meta_boxes', array( $this, 'add_combined_custom_post_what_is_involved_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_combined_meta_boxes_custom_post_types' ) );

		add_action( 'add_meta_boxes', array( $this, 'featuredVideo_add_custom_box' ) );
		add_action( 'save_post', array( $this, 'featuredVideo_save_postdata' ) );

		add_action( 'add_meta_boxes', array( $this, 'add_fl_events_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_meta_boxes_for_fl_events' ) );

		add_action( 'add_meta_boxes', array( $this, 'add_testimonial_url_meta_box' ) );
		add_action( 'save_post', array( $this, 'verify_nonce_and_update_testimonial_url_meta_box' ) );

		//$this->fields = apply_filters( 'ubc_metaboxes_fields', $this->fields );

		//add_filter( 'ubc_metaboxes_fields', array( $this, 'ubc_metaboxes_fields__addFieldsToFilter' ) );

		//add_action( 'save_post', array( $this, 'save_post__saveMetaboxes' ) );
	}

	/**
	* Metaboxes Admin Styles
	*
	* @author David Brabbins
	* @since 1.0
	* @param null
	* @return null
	*/

	public function meta_boxes_admin_styles() {

	  	global $typenow;

		if ( 'case-studies' == $typenow || 'projects' == $typenow || 'testimonial' == $typenow || 'events' == $typenow ) :

	        wp_enqueue_style( 'meta_boxes_admin_styles', plugin_dir_url( __FILE__ ) . 'assets/css/metabox-stylesheet.css', false, '1', 'all' );

	    endif;
	}

	/**
	 * Verify Nonce only
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param ($postName, $nonceName) $ - Verifies post name and nonce name
	 * @return ($post_id) -
	 */

	public function verifyNonceAndNotAutosave( $postName, $nonceName ) {

		// Check if our nonce is set.
		if ( ! isset( $_POST[ $postName ] ) )
			return false;

		$nonce = $_POST[ $postName ];

		// Verify that the nonce is valid.
		if ( ! wp_verify_nonce( $nonce, $nonceName ) )
			return false;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return false;

		return true;

	}

	/**
	 * Adds metabox for testimonial urls using a select option for each case study
	 *
	 * @author David Brabbins
	 * @since 1.0.4
	 * @param ($post_type)
	 * @return null
	 */

	public function add_testimonial_url_meta_box( $post_type ) {
	    $post_types = array( 'testimonial' );     //limit meta box to certain post types
		if ( in_array( $post_type, $post_types ) ) {
				add_meta_box(
					'testimonials_url_meta_box'
					,__( 'Testimonial URL' )
					,array( $this, 'html_field_for_testimonial_url_meta_box' )
					,$post_type
					,'side'
					,'high'
				);
		}
	}

	/**
	 * Verifying nonces, saving, permisisons and updating metabox
	 *
	 * @author David Brabbins
	 * @since 1.0.4
	 * @param $post_id
	 * @return
	 */

	public function verify_nonce_and_update_testimonial_url_meta_box( $post_id ) {

		if ( ! $this->verifyNonceAndNotAutosave( 'testimonial_url_nonce', 'save_testimonial_url' ) ) {
			return $post_id;
		}

		if ( ! isset( $_POST['post_type'] ) ) {
			return $post_id;
		}

		$postType = $_POST['post_type'];

		// Check the user's permissions.
		if ( 'testimonial' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;

		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		}

		//    $fl_testimonial_url_san = sanitize_text_field( $_POST['fl_testimonial_url'] );
		// update_post_meta( $post_id, '_fl_testimonial_url', $fl_testimonial_url_san );

		if ( isset( $_POST['fl_testimonial_select'] ) ) {
			$fl_testimonial_select_san = sanitize_text_field( $_POST['fl_testimonial_select'] );
		    update_post_meta( $post_id, '_fl_testimonial_select', $fl_testimonial_select_san );
		}

	}

	/**
	 * html query and html for case study pages and testimonal url setup. Only passing the post id's
	 *
	 * @author David Brabbins
	 * @since 1.0
	 * @param (array) $caseStudies_args- The attributes for this array
	 * @return null
	 */

	public function html_field_for_testimonial_url_meta_box( $post ) {

		$nonceField = wp_nonce_field( 'save_testimonial_url', 'testimonial_url_nonce' );

		//$fl_testimonial_url  = get_post_meta( $post->ID, '_fl_testimonial_url', true );
		$fl_testimonial_url_from_select  = get_post_meta( $post->ID, '_fl_testimonial_select', true );

		$caseStudies_args = array(
			'post_type'              => 'case-studies',
			'pagination'             => false,
			'posts_per_page'         => '100',
			'order'                  => 'DESC',
			'orderby'                => 'date',
		);

		// The Query
		$caseStudies_query = new WP_Query( $caseStudies_args );

		echo '<label for="fl_testimonial_select">';
		esc_attr_e( 'Case Studies:' );
		echo '</label>';

		if ( $caseStudies_query->have_posts() ) {
			echo '<select id="fl_testimonial_select" name="fl_testimonial_select">';
			echo '<option disabled selected> -- select case study -- </option>';
			while ( $caseStudies_query->have_posts() ) {

		 		$caseStudies_query->the_post(); ?>

				 <option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php selected( $fl_testimonial_url_from_select, get_the_ID() ); ?>><?php echo esc_attr( get_the_title() ); ?></option>

				<?php
			}

			echo '</select>';
		}

		else {
			// no posts found
		}

		/* Restore original Post Data */
		wp_reset_postdata();

		// echo '<p><span class="dashicons dashicons-admin-links"></span> <label for="fl_testimonial_url"><strong>';
		// _e( 'Custom URL:' );
		// echo '</label></strong><br>';
		// echo '<input type="text" id="fl_testimonial_url" name="fl_testimonial_url"';
		// echo ' value="' . esc_attr( $fl_testimonial_url ) . '" size="25" /></p>';
	}

	/**
	 * Metabox call for descriptive titles for pages
	 *
	 * @author David Brabbins
	 * @since 1.01
	 * @param ($post_type) $ - pages
	 * @return (null) -
	 */

	public function add_descriptive_titles_pages_meta_boxes( $post_type ) {
	    $post_types = array( 'page', 'case-studies' );     //limit meta box to certain post types
		if ( in_array( $post_type, $post_types ) ) {
				add_meta_box(
					'special_titles_pages'
					,__( 'Special titles + excerpts' )
					,array( $this, 'html_field_for_descriptive_title_meta_box' )
					,$post_type
					,'side'
					,'high'
				);
		}
	}

	/**
	* Verify nonce for descriptive titles meta box
	*
	* @author David Brabbins
	* @since 1.01
	* @param ($postName, $nonceName) $ - post and nonce verification
	* @return null
	*/

	public function verify_nonce_and_update_descriptive_meta_box( $post_id ) {

		if ( ! $this->verifyNonceAndNotAutosave( 'save_meta_boxes_fields_descriptive_titles_nonce', 'save_fl_save_meta_boxes_fields_descriptive_titles' ) ) {
			return $post_id;
		}

		if ( ! isset( $_POST['post_type'] ) ) {
			return $post_id;
		}

		$postType = $_POST['post_type'];

		// Check the user's permissions.
		if ( 'page' == $_POST['post_type'] || 'case-studies' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;

		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		}

	    $fl_descriptive_title_san = sanitize_text_field( $_POST['fl_descriptive_title'] );
		update_post_meta( $post_id, '_fl_descriptive_title_key', $fl_descriptive_title_san );

		$fl_descriptive_excerpt_san = sanitize_text_field( $_POST['fl_descriptive_excerpt'] );
		update_post_meta( $post_id, '_fl_descriptive_excerpt_key', $fl_descriptive_excerpt_san );

	}

	/**
	 * html field for descriptive titles
	 *
	 * @author David Brabbins
	 * @since 1.01
	 * @param ($post) $ -the post
	 * @return ($fl_descriptive_title) - post meta
	 */


	public function html_field_for_descriptive_title_meta_box( $post ) {

		$nonceField = wp_nonce_field( 'save_fl_save_meta_boxes_fields_descriptive_titles', 'save_meta_boxes_fields_descriptive_titles_nonce' );

		$fl_descriptive_title = get_post_meta( $post->ID, '_fl_descriptive_title_key', true );
		$fl_descriptive_excerpt = get_post_meta( $post->ID, '_fl_descriptive_excerpt_key', true );

		echo '<p><label for="fl_descriptive_title"><strong>';
		esc_attr_e( 'Enter the descriptive title:' );
		echo '</label></strong><br>';
		echo '<input type="text" id="fl_descriptive_title" name="fl_descriptive_title"';
		echo ' value="' . esc_attr( $fl_descriptive_title ) . '" size="25" /></p>';

		echo '<p><label for="fl_descriptive_excerpt"><strong>';
		esc_attr_e( 'Enter the descriptive excerpt:' );
		echo '</label></strong><br>';
		echo '<textarea type="text" id="fl_descriptive_excerpt" name="fl_descriptive_excerpt"';
		echo 'size="25" />' . esc_attr( $fl_descriptive_excerpt ) . '</textarea></p>';
		echo '<small>';
		esc_attr_e( 'This excerpt can be used on the homepages 6 pillars description and on the case studies archive page under the featured case study.' );
		echo '</small>';
	}

	/**
	* Adds The What is Inovlved Metabox used for Case Studies and Projects
	*
	* @author David Brabbins
	* @since 1.0
	* @param null
	* @return null
	*/

	public function add_combined_custom_post_what_is_involved_meta_boxes( $post_type ) {
		$post_types = array( 'case-studies', 'projects' );     //limit meta box to certain post types
		if ( in_array( $post_type, $post_types ) ) {
			add_meta_box(
				'what_is_involved'
				,__( 'What is inolved?' )
				,array( $this, 'combined_meta_boxes_custom_post_types' )
				,$post_type
				,'side'
				,'high'
			);
		}
	}

	/**
	* The What is Inovlved Metabox nonce check, user vef and save
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post_id
	* @return null
	*/

	public function save_combined_meta_boxes_custom_post_types( $post_id ) {

		if ( ! $this->verifyNonceAndNotAutosave( 'save_combined_meta_boxes_custom_post_types_nonce', 'save_fl_combined_meta_boxes_custom_post_types' ) ) {
			return $post_id;
		}

		if ( ! isset( $_POST['post_type'] ) ) {
			return $post_id;
		}

		$postType = $_POST['post_type'];

		//if ( $postType != 'case-studies' && $postType != 'projects' ) {
		if ( 'case-studies' != $postType && 'projects' != $postType ) {

			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return $post_id;
			}
		}

		/* OK, its safe for us to save the data now. */

		if ( isset( $_POST['fl_people_involved'] ) ) :
			$fl_people_san = sanitize_text_field( $_POST['fl_people_involved'] );
			update_post_meta( $post_id, '_person_meta_value_key', $fl_people_san );
		endif;

		$fl_dept_faculty_san = sanitize_text_field( $_POST['fl_dept_faculty'] );
		update_post_meta( $post_id, '_dept_faculty_meta_value_key', $fl_dept_faculty_san );

		$fl_course_san = sanitize_text_field( $_POST['fl_course'] );
		update_post_meta( $post_id, '_course_meta_value_key', $fl_course_san );

		$fl_enrolment_san = sanitize_text_field( $_POST['fl_enrolment'] );
		update_post_meta( $post_id, '_enrolment_meta_value_key', $fl_enrolment_san );

	    $meta_select_san = sanitize_text_field( $_POST['meta-select'] );

	    update_post_meta( $post_id, '_prfx_stored_meta', $meta_select_san );

	    $fl_persons_san = $_POST['fl_persons'];
			update_post_meta( $post_id,'_fl_persons', $fl_persons_san );
	}

	/**
	* The What is Inovlved Metabox form fields
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post
	* @return null
	*/
	public function combined_meta_boxes_custom_post_types( $post ) {

		// Add an nonce field so we can check for it later.
		$nonceField = wp_nonce_field( 'save_fl_combined_meta_boxes_custom_post_types', 'save_combined_meta_boxes_custom_post_types_nonce' );

		// Use get_post_meta to retrieve an existing value from the database.
		$fl_person = get_post_meta( $post->ID, '_person_meta_value_key', true );
		$fl_dept_faculty = get_post_meta( $post->ID, '_dept_faculty_meta_value_key', true );
		$fl_course = get_post_meta( $post->ID, '_course_meta_value_key', true );
		$fl_enrolment = get_post_meta( $post->ID, '_enrolment_meta_value_key', true );
		$fl_school_radio = get_post_meta( $post->ID, '_school_meta_value_key', true );
		$prfx_stored_meta = get_post_meta( $post->ID, '_prfx_stored_meta', true );
		$fl_persons = get_post_meta( $post->ID,'_fl_persons' );  ?>

		<div id="meta_inner" class="meta_inner">
			<label for="fl_persons" class="prfx-row-title"><strong>Enter the people involved:</strong></label><br>
	    <?php $c = 0;
	    	$fl_persons = get_post_meta( $post->ID,'_fl_persons', true );
		if ( is_array( $fl_persons ) ) {
			foreach ( $fl_persons as $person ) {
				if ( isset( $person['name'] ) || isset( $person['title'] ) ) {
		                printf( '<div class="fl-persons"><p>Persons Name:<br><input type="text" name="fl_persons[%1$s][name]" value="%2$s" /><br>Title:<br><input type="text" name="fl_persons[%1$s][title]" value="%3$s" /><br><span class="remove">%4$s</span><hr></p></div>', esc_attr( $c ), esc_attr( $person['name'] ), esc_attr( $person['title'] ), __( 'Remove Person' ) );
		                $c = $c + 1;
				}
				else {
		            	echo 'no';
				}
			}
		}
		?>

		<span id="here"></span>
		<button class="add button button-orange button-large"><span class="dashicons dashicons-id"></span> <?php esc_attr_e( 'Add Person' ); ?></button>
		<script>
		    var $ =jQuery.noConflict();
		    $(document).ready(function() {
		        var count = <?php echo $c; ?>;
		        $(".add").click(function() {
		            count = count + 1;

		            $('#here').append('<p> Person:<br> <input type="text" name="fl_persons['+count+'][name]" value="" /> <br> Postion/Title:<br> <input type="text" name="fl_persons['+count+'][title]" value="" /><br><br><span class="remove">Remove Person</span><hr></p>' );
		            return false;
		        });
		        $(".remove").live('click', function() {
		            $(this).parent().remove();
		        });
		    });
		    </script>
		</div>

	    <?php

		// UBC_Helpers::LoadTemplate( dirname( _FILE__ ) . '/templates/meta_box_markup.php' );
		// Display the form, using the current value.
		//echo '<p><label for="fl_people_involved"><strong>';
		//_e( 'Enter the people involved.' );
		//echo '</strong></label><br> ';
		//echo '<input type="text" id="fl_people_involved" name="fl_people_involved"';
		//echo ' value="' . esc_attr( $fl_person ) . '" size="25" /></p>';
?><p>
		    <label for="meta-select" class="prfx-row-title"><?php esc_attr_e( 'Select:', 'prfx-textdomain' )?></label><br>
		    <select name="meta-select" id="meta-select">
		        <option value="Faculty" <?php selected( $prfx_stored_meta, 'Faculty' ); ?>> <?php esc_attr_e( 'Faculty' )?></option>
		        <option value="Department" <?php selected( $prfx_stored_meta, 'Department' ); ?>> <?php esc_attr_e( 'Department' )?></option>
		     	<option value="School" <?php selected( $prfx_stored_meta, 'School' ); ?>> <?php esc_attr_e( 'School' )?></option>
		    </select>
		</p><?php

		echo '<p><label for="fl_dept_faculty"><strong>';
		esc_attr_e( 'Enter the Department, Faculty or School' );
		echo '</label></strong><br>';
		echo '<input type="text" id="fl_dept_faculty" name="fl_dept_faculty"';
		echo ' value="' . esc_attr( $fl_dept_faculty ) . '" size="25" /></p>';

		echo '<p><label for="fl_course"><strong>';
		esc_attr_e( 'Enter Course(s)' );
		echo '</strong></label>';
		echo '<input type="text" id="fl_course" name="fl_course"';
		echo ' value="' . esc_attr( $fl_course ) . '" size="25" /><p>';

		echo '<p><label for="fl_enrolment"><strong>';
		esc_attr_e( 'Enter Enrolment' );
		echo '</strong></label>';
		echo '<input type="text" id="fl_enrolment" name="fl_enrolment"';
		echo ' value="' . esc_attr( $fl_enrolment ) . '" size="25" /><p>';

	}

	/**
		 * Adds Featured Video Metabox to Case Studies
		 *
		 * @author David Brabbins
		 * @since 1.0
		 * @param $post_type
		 * @return null
	*/

	public function featuredVideo_add_custom_box( $post_type ) {

		$post_types = array( 'case-studies' );     //limit meta box to certain post types
		if ( in_array( $post_type, $post_types ) ) {
				add_meta_box(
					'featuredVideo_sectionid'
					,__( 'Featured Video' )
					,array( $this, 'featuredVideo_inner_custom_box' )
					,$post_type
					,'side'
					,'high'
				);
		}
	}

	/**
	* Featured video metabox for Case Studies nonce check, user vef and save
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post_id
	* @return null
	*/

	public function featuredVideo_save_postdata( $post_id ) {

		if ( ! $this->verifyNonceAndNotAutosave( 'save_featured_video_meta_boxes_custom_post_types_nonce', 'save_featured_video_combined_meta_boxes_custom_post_types' ) ) {
			return $post_id;
		}

		if ( ! isset( $_POST['post_type'] ) ) {
			return $post_id;
		}

		$postType = $_POST['post_type'];

		// Check the user's permissions.
		if ( 'case-studies' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;

		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		}

	    $featured_video_san = sanitize_text_field( $_POST['featuredVideoURL_field'] );
	    update_post_meta( $post_id, '_featuredVideoURL', $featured_video_san );

	    $video_select_san = sanitize_text_field( $_POST['video-select'] );
	    update_post_meta( $post_id, '_video_type_media', $video_select_san );
	}

	/**
	* Featured video metabox fields
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post
	* @return null
	*/

	public function featuredVideo_inner_custom_box( $post, $width = 680, $height = 360 ) {

		// Add an nonce field so we can check for it later.
		$nonceField = wp_nonce_field( 'save_featured_video_combined_meta_boxes_custom_post_types', 'save_featured_video_meta_boxes_custom_post_types_nonce' );

	    $featuredVideoURL = get_post_meta( $post->ID, '_featuredVideoURL', true );
	    //$VideoTypeMedia = get_post_meta( $post->ID, '_video_type_media', true );

	   	if ( 'YouTube' == $featuredVideoURL && $VideoTypeMedia ) :
	   		echo '<div class="responsive-media"><iframe width="680" height="360" src="//www.youtube.com/embed/'. esc_attr( $featuredVideoURL ) .'" frameborder="0" allowfullscreen="" id="popup-youtube-player" allowscriptaccess="always"></iframe></div>';
	   	endif;

	   	echo '<h4 style="margin: 10px 0 0 0;"><span class="dashicons dashicons-video-alt3"></span> Video ID</h4>';
	  //  	echo '<p>';
		// echo '<label for="video-select" class="prfx-row-title">'. esc_attr_e( 'Select video type:', 'prfx-textdomain' ) .'</label><br>';
		// echo '<select name="video-select" id="video-select">';
		// echo '<option value="YouTube" '. selected( $VideoTypeMedia, 'YouTube' ) .'>';
		// echo  esc_attr_e( 'YouTube' ) .'</option>';
		// echo '<option value="Media Site" '. selected( $VideoTypeMedia, 'Media Site' ) .' >';
		// echo  esc_attr_e( 'Media Site' ) .'</option>';
		// echo '</select>';
		// echo '</p>';
	   	echo '<input type="text" id="featuredVideoURL_field" name="featuredVideoURL_field" value="'. esc_attr( $featuredVideoURL ) .'" style="width: 100%;" /><br>';
	    echo '<small>https://www.youtube.com/watch?v=<strong>"PCgUM1jKtdg"</strong></small>';
	}

	/**
	* Adds Event Date Picker for Events
	*
	* @author David Brabbins
	* @since 1.0
	* @param null
	* @return null
	*/

	public function custom_post_type_event_scripts() {
	    global $typenow;

		if ( 'events' == $typenow ) {
	        wp_enqueue_script( 'jquery-ui-datepicker' );
					wp_enqueue_style( 'jquery-ui-style', '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.2/themes/smoothness/jquery-ui.css', true );
	    }
	}

	/**
	* Adds Event Date Picker Metabox for Events
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post_type
	* @return null
	*/

	public function add_fl_events_meta_box( $post_type ) {
		$post_types = array( 'events' );     //limit meta box to certain post types
		if ( in_array( $post_type, $post_types ) ) {
			add_meta_box(
				'event_date_link_meta_box'
				,__( 'Event Date and Link' )
				,array( $this, 'meta_box_for_events_custom_post_type' )
				,$post_type
				,'normal'
				,'high'
			);
		}
	}

	/**
	* Adds Event Date Picker for Events nonce check, user vef and save
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post_id
	* @return null
	*/


	public function save_meta_boxes_for_fl_events( $post_id ) {

		// Check if our nonce is set.
		if ( ! isset( $_POST['save_meta_boxes_for_events_post_types_nonce'] ) )
			return $post_id;

		$nonce = $_POST['save_meta_boxes_for_events_post_types_nonce'];

		// Verify that the nonce is valid.
		if ( ! wp_verify_nonce( $nonce, 'save_meta_boxes_for_events_post_types' ) )
			return $post_id;

		// If this is an autosave, our form has not been submitted,
		//     so we don't want to do anything.
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

		// Check the user's permissions.
		if ( 'page' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;

		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		}

		$fl_event_link_san = sanitize_text_field( $_POST['fl_event_link'] );

		$fl_event_link_san = trim( $fl_event_link_san, '/' );

		// If scheme not included, prepend it
		if ( ! preg_match( '#^http(s)?://#', $fl_event_link_san ) ) {
		    $fl_event_link_san = 'http://' . $fl_event_link_san;
		}

		//$urlParts = parse_url($fl_event_link_san);

		// remove www
		//$domain = preg_replace('/^www\./', '', $urlParts['host']);

		update_post_meta( $post_id, '_fl_event_link_meta_value_key', $fl_event_link_san );

		$fl_event_start_date_san = sanitize_text_field( $_POST['fl-start-date'] );
		$date_convert = strtotime( $fl_event_start_date_san );
		update_post_meta( $post_id, '_fl_start_date_meta_value_key', $fl_event_start_date_san );

		$fl_event_end_date_san = sanitize_text_field( $_POST['fl-end-date'] );
		update_post_meta( $post_id, '_fl_end_date_meta_value_key', $fl_event_end_date_san );

		$fl_event_time_san = sanitize_text_field( $_POST['fl-end-time'] );
		update_post_meta( $post_id, '_fl_event_time_meta_value_key', $fl_event_time_san );

		$fl_event_hidden_end_date_san = sanitize_text_field( $_POST['fl-end-date'] ) . $fl_event_time_san;
		$fl_event_hidden_end_date_san = strtotime( $fl_event_hidden_end_date_san );
		update_post_meta( $post_id, '_fl_hidden_end_date_meta_value_key', $fl_event_hidden_end_date_san );

	}

	/**
	* Event Date Picker for Events jQuery and fields
	*
	* @author David Brabbins
	* @since 1.0
	* @param $post
	* @return null
	*/

	public function meta_box_for_events_custom_post_type( $post ) {

		// Add an nonce field so we can check for it later.
		$nonceField = wp_nonce_field( 'save_meta_boxes_for_events_post_types', 'save_meta_boxes_for_events_post_types_nonce' );

		// Use get_post_meta to retrieve an existing value from the database.
		$fl_event_start_date = get_post_meta( $post->ID, '_fl_start_date_meta_value_key', true );
		$fl_event_end_date = get_post_meta( $post->ID, '_fl_end_date_meta_value_key', true );
		$fl_event_time = get_post_meta( $post->ID, '_fl_event_time_meta_value_key', true );
		$fl_event_link = get_post_meta( $post->ID, '_fl_event_link_meta_value_key', true );

		echo "<script>
		jQuery(document).ready(function(){
			jQuery('.fl-date').datepicker({
				dateFormat : 'MM d, yy'
			});
		});
		</script>";

		echo '<p><label for="fl-start-date"><strong><span class="dashicons dashicons-calendar-alt"></span> ';
		esc_attr_e( 'Start date:' );
		echo '</label></strong><br>';
		echo '<input type="text" name="fl-start-date" class="fl-date" id="fl-start-date" value="' . esc_attr( $fl_event_start_date ). '" /></p>';

		echo '<p><label for="fl-end-date"><strong><span class="dashicons dashicons-calendar-alt"></span> ';
		esc_attr_e( 'End date:' );
		echo '</label></strong><br>';
		echo '<input type="text" name="fl-end-date" class="fl-date" id="fl-end-date" value="' . esc_attr( $fl_event_end_date ). '" /></p>';
		esc_attr_e( 'Use this field if the start and end date are the same. ie. July 1st, 2015' );

		echo '<p><label for="fl-end-time"><strong><span class="dashicons dashicons-clock"></span> ';
		esc_attr_e( 'Time:' );
		echo '</label></strong><br>';
		echo '<input type="text" name="fl-end-time" class="fl-time" id="fl-end-time" value="' . esc_attr( $fl_event_time ). '" /></p>';

		echo '<p><span class="dashicons dashicons-admin-links"></span> <label for="fl_event_link"><strong>';
		esc_attr_e( 'Event URL:' );
		echo '</label></strong><br>';
		echo '<input type="text" id="fl_event_link" name="fl_event_link"';
		echo ' value="' . esc_attr( $fl_event_link ) . '" size="25" /></p>';

	}

} //CTLT_Custom_Metaboxes

add_action( 'plugins_loaded', 'plugins_loaded__instantiateCTLT_Custom_Metaboxes', 10 );

function plugins_loaded__instantiateCTLT_Custom_Metaboxes() {
	$CTLTCustomTemplates = new CTLT_Flexible_Learning_Custom_Metaboxes();
}

?>
